"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toRendableStand = exports.toRendableSkiRental = void 0;

var _utils = require("./utils");

const toRendableFromGateway = (intl, inscription) => {
  const {
    id,
    days,
    time,
    items,
    price,
    title,
    nbDays,
    meeting
  } = inscription;
  return {
    id,
    label: title,
    pax: items.length > 1 ? `${items.length} ${intl.formatMessage({
      id: "otherproducts.people"
    })}` : items[0].client.first_name,
    price,
    details: [{
      type: "details",
      label: intl.formatMessage({
        id: "otherproducts.date"
      }),
      value: `${days} ${time} · ${nbDays}${intl.formatMessage({
        id: "otherproducts.days"
      })}`
    }, {
      type: "details",
      label: intl.formatMessage({
        id: "otherproducts.place"
      }),
      value: meeting
    }].filter(o => o)
  };
};

const toRendableLocale = (intl, inscription, isStand) => {
  const {
    id,
    renter,
    products,
    price,
    rentFrom,
    rentDuration,
    quantity
  } = inscription;
  const product = products[0];
  const options = products.filter(({
    type
  }) => type === "Option");
  const extras = products.filter(({
    type
  }) => type === "Extra");
  return {
    id,
    label: product.label,
    pax: renter,
    price: price,
    details: [{
      type: "details",
      label: isStand ? intl.formatMessage({
        id: "otherproducts.information"
      }) : intl.formatMessage({
        id: "otherproducts.date"
      }),
      value: isStand ? `${quantity} x ${rentDuration} | ${(0, _utils.format)(rentFrom, intl.locale)}` : `${(0, _utils.format)(rentFrom, intl.locale)} · ${rentDuration}`
    }, options.length > 0 ? {
      type: "details",
      label: intl.formatMessage({
        id: "otherproducts.included"
      }),
      value: options.map(option => option.label).join(", ")
    } : undefined, extras.length > 0 ? {
      type: "details",
      label: intl.formatMessage({
        id: "otherproducts.options"
      }),
      value: extras.map(extra => extra.label).join(", ")
    } : undefined].filter(o => o)
  };
};

const toRendableSkiRentalAndStand = (intl, cartLine, isStand = false) => {
  const {
    merchant,
    merchantName,
    inscriptions
  } = cartLine;
  return {
    code: merchant,
    name: merchantName,
    inscriptions: inscriptions.map(inscription => {
      if (inscription.products !== undefined) {
        return toRendableLocale(intl, inscription, isStand);
      } else {
        return toRendableFromGateway(intl, inscription);
      }
    })
  };
};

const toRendableSkiRental = (intl, skiRental) => toRendableSkiRentalAndStand(intl, skiRental, false);

exports.toRendableSkiRental = toRendableSkiRental;

const toRendableStand = (intl, stand) => toRendableSkiRentalAndStand(intl, stand, true);

exports.toRendableStand = toRendableStand;