"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.post = exports.put = exports.get = exports.fetcher = void 0;

var _logger = _interopRequireDefault(require("./logger"));

var _isomorphicFetch = _interopRequireDefault(require("isomorphic-fetch"));

var _nodeAbortController = _interopRequireDefault(require("node-abort-controller"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fetcher = (method = "POST") => async (url, payload, options = {}) => {
  const {
    headers,
    logger = _logger.default.info,
    timeout = 60000
  } = options;
  let responseCloned;

  try {
    const body = payload !== undefined && typeof payload !== "string" ? JSON.stringify(payload) : payload;
    logger(`request: ${method}, ${url}`);
    logger(`headers:${JSON.stringify(headers)}`);
    logger(`body:${body}`);
    const start = new Date();
    const controller = new _nodeAbortController.default();
    const signal = controller.signal;
    const response = await (0, _isomorphicFetch.default)(url, {
      method,
      headers,
      body,
      signal
    });
    setTimeout(() => {
      controller.abort();
    }, timeout);

    if (url.includes("s-money.fr")) {
      responseCloned = response.clone();
    }

    const json = await response.json();
    const stop = new Date();
    const duration = stop.getTime() - start.getTime();

    _logger.default.debug(`${method} ${url} : ${duration}ms`);

    logger(`response to ${url}`);

    if (response.ok === false) {
      const error = json && json.error !== undefined ? json : {
        error: json
      };
      logger(JSON.stringify(error));
      return Promise.reject(error);
    } else {
      logger(JSON.stringify(json));
      return json;
    }
  } catch (err) {
    logger(`ERROR response to ${method} ${url}`);

    _logger.default.error(`ERROR response to ${method} ${url}`);

    _logger.default.error(`Body : ${JSON.stringify(payload)}`);

    _logger.default.error(err.message, err.stack);

    if (responseCloned !== undefined) {
      const respText = await responseCloned.text();

      _logger.default.error(`RAW RESPONSE : ${respText}`);
    }

    throw err;
  }
};

exports.fetcher = fetcher;

const get = (url, options) => fetcher("GET")(url, undefined, options);

exports.get = get;
const put = fetcher("PUT");
exports.put = put;
const post = fetcher("POST");
exports.post = post;