"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.buildLogger = void 0;

require("winston-daily-rotate-file");

var _winston = _interopRequireDefault(require("winston"));

var _config = _interopRequireDefault(require("config"));

var _environment = require("./utils/environment");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  createLogger,
  format,
  transports
} = _winston.default;

const root = _config.default.get("logs");

const target = file => `${root}/${file}-%DATE%.log`;

const timestamp = () => {
  const d = new Date();
  return `${d.toLocaleDateString()} ${d.toLocaleTimeString()}`;
};

const logFormat = format.printf(({
  level,
  message
}) => {
  const msg = typeof message === "string" ? message : JSON.stringify(message);
  return `${timestamp()} [${level}] ${msg}`;
});
const defaultLogger = createLogger({
  level: "info",
  format: logFormat,
  transports: _environment.isDev ? new transports.Console({
    level: "debug"
  }) : [new transports.DailyRotateFile({ ..._config.default.logger,
    level: "error",
    filename: target("error")
  }), new transports.DailyRotateFile({ ..._config.default.logger,
    filename: target("application")
  })]
});

const buildLogger = prefix => createLogger({
  level: "info",
  format: logFormat,
  transports: _environment.isDev ? new transports.Console({
    level: "debug"
  }) : new transports.DailyRotateFile({ ..._config.default.logger,
    filename: target(prefix)
  })
});

exports.buildLogger = buildLogger;
var _default = {
  log: (msg, level = "info") => defaultLogger[level](msg),
  info: msg => defaultLogger.info(msg),
  error: msg => defaultLogger.error(msg),
  debug: msg => defaultLogger.debug(msg)
};
exports.default = _default;