"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.send = void 0;

var MailImages = _interopRequireWildcard(require("./mail-images"));

var ReactDOM = _interopRequireWildcard(require("react-dom/server"));

var _formData = _interopRequireDefault(require("form-data"));

var _nodeFetch = _interopRequireDefault(require("node-fetch"));

var _fs = _interopRequireDefault(require("fs"));

var _xmldom = require("xmldom");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// For react-intl in node environments
global.DOMParser = _xmldom.DOMParser;

const btoa = str => {
  const buf = Buffer.from(str, "utf-8");
  return buf.toString("base64");
};

const Seq = x => {
  return Array.isArray(x) ? x : [x];
};

const addAddresses = (body, name, addresses) => {
  if (addresses) {
    body.append(name, Seq(addresses).join(","));
  }
};

const wrapHtml = markup => {
  return `<!doctype html>
  <html>
    <head>
      <meta http-equiv="Content-Type" content="text/html charset=UTF-8" />
      <meta name="viewport" content="width=device-width, initial-scale=1 />
    </head>
    <body>${markup}</body>
  </html>`;
};

const send = async ({
  subject,
  from,
  to,
  cc = undefined,
  bcc = undefined,
  replyTo = undefined,
  html = undefined,
  text = undefined,
  inline = [],
  attachment = [],
  config
}) => {
  const auth = btoa(`api:${config.apiKey}`);
  const body = new _formData.default();
  body.append("from", from !== null && from !== void 0 ? from : config.sender);
  body.append("subject", subject);
  addAddresses(body, "to", to);
  addAddresses(body, "cc", cc);
  addAddresses(body, "bcc", bcc);
  addAddresses(body, "h:Reply-To", replyTo);

  if (html) {
    const rendered = ReactDOM.renderToStaticMarkup(html);
    const [markup, images] = await MailImages.embed(rendered);
    images.forEach(image => inline.push(image));
    body.append("html", wrapHtml(markup));
  }

  if (text) {
    body.append("text", text);
  }

  Seq(inline).forEach(path => {
    body.append("inline", _fs.default.createReadStream(path));
  });
  Seq(attachment).forEach(path => {
    body.append("attachment", _fs.default.createReadStream(path));
  });
  const response = await (0, _nodeFetch.default)(`https://${config.host}/v3/${config.domain}/messages`, {
    method: "POST",
    headers: {
      Authorization: `Basic ${auth}`
    },
    body
  });
  return response.json();
};

exports.send = send;