"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.embed = void 0;

var Image = _interopRequireWildcard(require("./image"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const STORE = "/mail-images";
const imgRegex = /<img [^>]*>/gi;

const extractImgTags = html => {
  const imgTags = [];

  while (true) {
    const match = imgRegex.exec(html);
    if (match === null) break;
    imgTags.push(match[0]);
  }

  return imgTags;
};

const srcRegex = /src="([^"]+)"/i;

const extractSrc = imgTag => {
  const attr = srcRegex.exec(imgTag);
  return attr !== null ? attr[1] : undefined;
};

const widthRegex = /width="([0-9]+)"/i;

const extractWidth = imgTag => {
  const attr = widthRegex.exec(imgTag);
  return attr !== null ? Number(attr[1]) : undefined;
};

const heightRegex = /height="([0-9]+)"/i;

const extractHeight = imgTag => {
  const attr = heightRegex.exec(imgTag);
  return attr !== null ? Number(attr[1]) : undefined;
};

const embedImage = async imgTag => {
  const src = extractSrc(imgTag);

  if (src !== undefined) {
    const width = extractWidth(imgTag);
    const height = extractHeight(imgTag);
    const options = {
      store: STORE,
      width,
      height
    };
    const image = await Image.forURL(src, options);
    const [imagePath, imageWidth, imageHeight] = image;

    const cid = _path.default.basename(imagePath);

    const newTag = `<img src="cid:${cid}" width="${imageWidth}" height="${imageHeight}" style="width:${imageWidth}px;height:${imageHeight}px;border:0;">`;
    return [newTag, imagePath];
  }
};

const embed = async markup => {
  let html = markup;
  const images = [];
  const imgTags = extractImgTags(markup);
  await Promise.all(imgTags.map(async imgTag => {
    const image = await embedImage(imgTag);

    if (image) {
      const [newTag, imagePath] = image;
      html = html.replace(imgTag, newTag);
      images.push(imagePath);
    }
  }));
  return [html, images];
};

exports.embed = embed;