"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.readResponse = exports.soapCall = exports.soapClient = void 0;

var _strongSoap = _interopRequireDefault(require("strong-soap"));

var _pick = require("./utils/pick");

var _result = require("./types/result");

var _logger = _interopRequireDefault(require("./logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = false;
const options = {
  time: true
};

const soapClient = (wsdl, extraOptions = {}) => new Promise((resolve, reject) => {
  _strongSoap.default.soap.createClient(wsdl, { ...options,
    ...extraOptions
  }, (error, client) => error !== null ? reject(error) : resolve(client));
});

exports.soapClient = soapClient;

const soapCall = (wsdl, extraOptions, client = undefined) => (method, path) => async args => {
  try {
    const service = client || (await soapClient(wsdl, extraOptions));
    const startTime = new Date().getTime();
    const {
      result,
      envelope
    } = await service[method](args);
    const stopTime = new Date().getTime();

    _logger.default.debug(`SOAP Call [${method}] : ${stopTime - startTime} ms`);

    if (debug) {
      _logger.default.debug(`SOAP Call [${method}] REQUEST : \n${service.lastRequest}`);

      _logger.default.debug(`SOAP Call [${method}] RESPONSE : \n${envelope}`);
    }

    return (0, _result.Success)((0, _pick.pickPath)(path, result));
  } catch (error) {
    _logger.default.error(error);

    return (0, _result.Failure)(error.message);
  }
};

exports.soapCall = soapCall;

const readResponse = xml => {
  const xmlHandler = new _strongSoap.default.soap.XMLHandler();
  return xmlHandler.xmlToJson(null, xml, null);
};

exports.readResponse = readResponse;