"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.HeadOption = exports.None = exports.Some = void 0;

var _assert = _interopRequireDefault(require("assert"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const isDefined = value => value !== undefined && value !== null;

const hasSome = ({
  some
}) => isDefined(some);

const hasNone = ({
  none
}) => isDefined(none);

const isValidMatcher = matcher => hasSome(matcher) && hasNone(matcher);

class Option {
  constructor(value) {
    this.value = value;
  }

  match(matcher) {
    (0, _assert.default)(isValidMatcher(matcher));
    return isDefined(this.value) ? matcher.some(this.value) : matcher.none();
  }

  get() {
    return this.value;
  }

  map(f) {
    return isDefined(this.value) ? Some(f(this.value)) : None();
  }

  getOrElse(value) {
    return isDefined(this.value) ? this.value : value;
  }

}

const Some = value => new Option(value);

exports.Some = Some;

const None = () => new Option(undefined);

exports.None = None;

const HeadOption = array => isDefined(array) && Array.isArray(array) && array.length > 0 ? Some(array[0]) : None();

exports.HeadOption = HeadOption;